
The login functionality should always generate (and use) a new session id  
-------

**Description:**

Whenever an user is successfully authenticated the application should generate a 
new session cookie.


**Solution:**

The login functionality should always generate (and use) a new session id after a 
successful login. This is done to prevent an attacker doing a session fixation attack
on your users. 


	